==> xmedcon-0.5.2.tar.gz: xmedcon-0.5.2/source/xpages.h <==
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
 * filename: xpages.h                                                      *
 *                                                                         *
 * UTIL C-source: Medical Image Conversion Utility                         *
 *                                                                         *
 * purpose      : xpages.c header file                                     *
 *                                                                         *
 * project      : (X)MedCon by Erik Nolf                                   *
 *                                                                         *
 * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/* $Id: xpages.h,v 1.1.1.1 2000/10/28 16:51:55 enlf Exp $
 */

/*
   Copyright (C) 1997-2000 by Erik Nolf

   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
   Free Software Foundation; either version 2, or (at your option) any later
   version.

   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
   Public License for more details.

   You should have received a copy of the GNU General Public License along
   with this program; if not, write to the Free Software Foundation, Inc.,
   59 Place - Suite 330, Boston, MA 02111-1307, USA.  */

#ifndef __XPAGES_H__
#define __XPAGES_H__

/****************************************************************************
                            F U N C T I O N S
****************************************************************************/

void XMdcPagesSelected(GtkWidget *widget, Uint32 *pagenr);
GtkWidget *XMdcPagesCreateMenu(void);
void XMdcPagesNext(void);
void XMdcPagesPrev(void);
void XMdcPagesToFrames(void);
void XMdcPagesNotToFrames(void);

#endif

==> xmedcon_0.9.8.1.orig.tar.gz: xmedcon-0.9.8.1/source/xpages.h <==
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
 * filename: xpages.h                                                      *
 *                                                                         *
 * UTIL C-source: Medical Image Conversion Utility                         *
 *                                                                         *
 * purpose      : xpages.c header file                                     *
 *                                                                         *
 * project      : (X)MedCon by Erik Nolf                                   *
 *                                                                         *
 * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/* $Id: xpages.h,v 1.8 2004/01/04 22:36:17 enlf Exp $
 */

/*
   Copyright (C) 1997-2004 by Erik Nolf

   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
   Free Software Foundation; either version 2, or (at your option) any later
   version.

   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
   Public License for more details.

   You should have received a copy of the GNU General Public License along
   with this program; if not, write to the Free Software Foundation, Inc.,
   59 Place - Suite 330, Boston, MA 02111-1307, USA.  */

#ifndef __XPAGES_H__
#define __XPAGES_H__

/****************************************************************************
                            F U N C T I O N S
****************************************************************************/

void XMdcPagesSelected(GtkWidget *widget, Uint32 *pagenr);
gboolean XMdcPagesGoTo(GtkWidget *spinner, gpointer data);
GtkWidget *XMdcPagesCreateMenu(void);
void XMdcPagesNext(void);
void XMdcPagesPrev(void);
void XMdcPagesSelCallbackApply(GtkWidget *widget, gpointer data);
void XMdcPagesSel(void);
Uint32 XMdcPagesGetNrImages(void);

#endif
